message_log Package
===================

:mod:`admin` Module
-------------------

.. automodule:: yawf.message_log.admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`models` Module
--------------------

.. automodule:: yawf.message_log.models
    :members:
    :undoc-members:
    :show-inheritance:
